---
title: <span class="badge object-type-scalar"></span> Hectares
---
# <span class="badge object-type-scalar"></span> Hectares

Area: Hectares (ha)

## Definition

```python
# Area: Hectares (ha)
Hectares: typing.Literal["hectares"] = "hectares"
```
